# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..epi import EpiReg


def test_EpiReg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        echospacing=dict(argstr="--echospacing=%f",),
        environ=dict(nohash=True, usedefault=True,),
        epi=dict(argstr="--epi=%s", extensions=None, mandatory=True, position=-4,),
        fmap=dict(argstr="--fmap=%s", extensions=None,),
        fmapmag=dict(argstr="--fmapmag=%s", extensions=None,),
        fmapmagbrain=dict(argstr="--fmapmagbrain=%s", extensions=None,),
        no_clean=dict(argstr="--noclean", usedefault=True,),
        no_fmapreg=dict(argstr="--nofmapreg",),
        out_base=dict(argstr="--out=%s", position=-1, usedefault=True,),
        output_type=dict(),
        pedir=dict(argstr="--pedir=%s",),
        t1_brain=dict(
            argstr="--t1brain=%s", extensions=None, mandatory=True, position=-2,
        ),
        t1_head=dict(argstr="--t1=%s", extensions=None, mandatory=True, position=-3,),
        weight_image=dict(argstr="--weight=%s", extensions=None,),
        wmseg=dict(argstr="--wmseg=%s", extensions=None,),
    )
    inputs = EpiReg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EpiReg_outputs():
    output_map = dict(
        epi2str_inv=dict(extensions=None,),
        epi2str_mat=dict(extensions=None,),
        fmap2epi_mat=dict(extensions=None,),
        fmap2str_mat=dict(extensions=None,),
        fmap_epi=dict(extensions=None,),
        fmap_str=dict(extensions=None,),
        fmapmag_str=dict(extensions=None,),
        fullwarp=dict(extensions=None,),
        out_1vol=dict(extensions=None,),
        out_file=dict(extensions=None,),
        seg=dict(extensions=None,),
        shiftmap=dict(extensions=None,),
        wmedge=dict(extensions=None,),
        wmseg=dict(extensions=None,),
    )
    outputs = EpiReg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..mesh import WarpPoints


def test_WarpPoints_inputs():
    input_map = dict(
        interp=dict(mandatory=True, usedefault=True,),
        out_points=dict(
            extensions=None,
            keep_extension=True,
            name_source="points",
            name_template="%s_warped",
            output_name="out_points",
        ),
        points=dict(extensions=None, mandatory=True,),
        warp=dict(extensions=None, mandatory=True,),
    )
    inputs = WarpPoints.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_WarpPoints_outputs():
    output_map = dict(out_points=dict(extensions=None,),)
    outputs = WarpPoints.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import QualityIndex


def test_QualityIndex_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        autoclip=dict(argstr="-autoclip", usedefault=True, xor=["mask"],),
        automask=dict(argstr="-automask", usedefault=True, xor=["mask"],),
        clip=dict(argstr="-clip %f",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        interval=dict(argstr="-range", usedefault=True,),
        mask=dict(argstr="-mask %s", extensions=None, xor=["autoclip", "automask"],),
        out_file=dict(
            argstr="> %s",
            extensions=None,
            keep_extension=False,
            name_source=["in_file"],
            name_template="%s_tqual",
            position=-1,
        ),
        quadrant=dict(argstr="-quadrant", usedefault=True,),
        spearman=dict(argstr="-spearman", usedefault=True,),
    )
    inputs = QualityIndex.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_QualityIndex_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = QualityIndex.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import BrickStat


def test_BrickStat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        mask=dict(argstr="-mask %s", extensions=None, position=2,),
        max=dict(argstr="-max",),
        mean=dict(argstr="-mean",),
        min=dict(argstr="-min", position=1,),
        percentile=dict(argstr="-percentile %.3f %.3f %.3f",),
        slow=dict(argstr="-slow",),
        sum=dict(argstr="-sum",),
        var=dict(argstr="-var",),
    )
    inputs = BrickStat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BrickStat_outputs():
    output_map = dict(min_val=dict(),)
    outputs = BrickStat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..maxcurvature import maxcurvature


def test_maxcurvature_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        image=dict(argstr="--image %s", extensions=None,),
        output=dict(argstr="--output %s", hash_files=False,),
        sigma=dict(argstr="--sigma %f",),
        verbose=dict(argstr="--verbose ",),
    )
    inputs = maxcurvature.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_maxcurvature_outputs():
    output_map = dict(output=dict(extensions=None,),)
    outputs = maxcurvature.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import ModelFit


def test_ModelFit_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bgmask=dict(argstr="-bgmask %s", extensions=None,),
        bgthresh=dict(argstr="-bgthresh %G",),
        cfthresh=dict(argstr="-csfthresh %G",),
        environ=dict(nohash=True, usedefault=True,),
        fixedbvalue=dict(argstr="-fixedbvalue %s",),
        fixedmodq=dict(argstr="-fixedmod %s",),
        in_file=dict(argstr="-inputfile %s", extensions=None, mandatory=True,),
        inputdatatype=dict(argstr="-inputdatatype %s",),
        model=dict(argstr="-model %s", mandatory=True,),
        noisemap=dict(argstr="-noisemap %s", extensions=None,),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        outlier=dict(argstr="-outliermap %s", extensions=None,),
        outputfile=dict(argstr="-outputfile %s", extensions=None,),
        residualmap=dict(argstr="-residualmap %s", extensions=None,),
        scheme_file=dict(argstr="-schemefile %s", extensions=None, mandatory=True,),
        sigma=dict(argstr="-sigma %G",),
        tau=dict(argstr="-tau %G",),
    )
    inputs = ModelFit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ModelFit_outputs():
    output_map = dict(fitted_data=dict(extensions=None,),)
    outputs = ModelFit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..connectivity import Conmat


def test_Conmat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-inputfile %s", extensions=None, mandatory=True,),
        output_root=dict(argstr="-outputroot %s", extensions=None, genfile=True,),
        scalar_file=dict(
            argstr="-scalarfile %s", extensions=None, requires=["tract_stat"],
        ),
        target_file=dict(argstr="-targetfile %s", extensions=None, mandatory=True,),
        targetname_file=dict(argstr="-targetnamefile %s", extensions=None,),
        tract_prop=dict(argstr="-tractstat %s", units="NA", xor=["tract_stat"],),
        tract_stat=dict(
            argstr="-tractstat %s",
            requires=["scalar_file"],
            units="NA",
            xor=["tract_prop"],
        ),
    )
    inputs = Conmat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Conmat_outputs():
    output_map = dict(
        conmat_sc=dict(extensions=None,), conmat_ts=dict(extensions=None,),
    )
    outputs = Conmat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Level1Design


def test_Level1Design_inputs():
    input_map = dict(
        bases=dict(field="bases", mandatory=True,),
        factor_info=dict(field="fact",),
        flags=dict(),
        global_intensity_normalization=dict(field="global",),
        interscan_interval=dict(field="timing.RT", mandatory=True,),
        mask_image=dict(extensions=None, field="mask",),
        mask_threshold=dict(usedefault=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        microtime_onset=dict(field="timing.fmri_t0",),
        microtime_resolution=dict(field="timing.fmri_t",),
        model_serial_correlations=dict(field="cvi",),
        paths=dict(),
        session_info=dict(field="sess", mandatory=True,),
        spm_mat_dir=dict(field="dir",),
        timing_units=dict(field="timing.units", mandatory=True,),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        volterra_expansion_order=dict(field="volt",),
    )
    inputs = Level1Design.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Level1Design_outputs():
    output_map = dict(spm_mat_file=dict(extensions=None,),)
    outputs = Level1Design.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import AI


def test_AI_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        convergence=dict(argstr="-c [%d,%g,%d]", usedefault=True,),
        dimension=dict(argstr="-d %d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        fixed_image=dict(extensions=None, mandatory=True,),
        fixed_image_mask=dict(argstr="-x %s", extensions=None,),
        metric=dict(argstr="-m %s", mandatory=True,),
        moving_image=dict(extensions=None, mandatory=True,),
        moving_image_mask=dict(extensions=None, requires=["fixed_image_mask"],),
        num_threads=dict(nohash=True, usedefault=True,),
        output_transform=dict(argstr="-o %s", extensions=None, usedefault=True,),
        principal_axes=dict(argstr="-p %d", usedefault=True, xor=["blobs"],),
        search_factor=dict(argstr="-s [%g,%g]", usedefault=True,),
        search_grid=dict(argstr="-g %s",),
        transform=dict(argstr="-t %s[%g]", usedefault=True,),
        verbose=dict(argstr="-v %d", usedefault=True,),
    )
    inputs = AI.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_AI_outputs():
    output_map = dict(output_transform=dict(extensions=None,),)
    outputs = AI.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Remlfit


def test_Remlfit_inputs():
    input_map = dict(
        STATmask=dict(argstr="-STATmask %s", extensions=None,),
        addbase=dict(argstr="-addbase %s", copyfile=False, sep=" ",),
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask", usedefault=True,),
        dsort=dict(argstr="-dsort %s", copyfile=False, extensions=None,),
        dsort_nods=dict(argstr="-dsort_nods", requires=["dsort"],),
        environ=dict(nohash=True, usedefault=True,),
        errts_file=dict(argstr="-Rerrts %s", extensions=None,),
        fitts_file=dict(argstr="-Rfitts %s", extensions=None,),
        fout=dict(argstr="-fout",),
        glt_file=dict(argstr="-Rglt %s", extensions=None,),
        gltsym=dict(argstr='-gltsym "%s" %s...',),
        goforit=dict(argstr="-GOFORIT",),
        in_files=dict(argstr='-input "%s"', copyfile=False, mandatory=True, sep=" ",),
        mask=dict(argstr="-mask %s", extensions=None,),
        matim=dict(argstr="-matim %s", extensions=None, xor=["matrix"],),
        matrix=dict(argstr="-matrix %s", extensions=None, mandatory=True,),
        nobout=dict(argstr="-nobout",),
        nodmbase=dict(argstr="-nodmbase", requires=["addbase", "dsort"],),
        nofdr=dict(argstr="-noFDR",),
        num_threads=dict(nohash=True, usedefault=True,),
        obeta=dict(argstr="-Obeta %s", extensions=None,),
        obuck=dict(argstr="-Obuck %s", extensions=None,),
        oerrts=dict(argstr="-Oerrts %s", extensions=None,),
        ofitts=dict(argstr="-Ofitts %s", extensions=None,),
        oglt=dict(argstr="-Oglt %s", extensions=None,),
        out_file=dict(argstr="-Rbuck %s", extensions=None,),
        outputtype=dict(),
        ovar=dict(argstr="-Ovar %s", extensions=None,),
        polort=dict(argstr="-polort %d", xor=["matrix"],),
        quiet=dict(argstr="-quiet",),
        rbeta_file=dict(argstr="-Rbeta %s", extensions=None,),
        rout=dict(argstr="-rout",),
        slibase=dict(argstr="-slibase %s",),
        slibase_sm=dict(argstr="-slibase_sm %s",),
        tout=dict(argstr="-tout",),
        usetemp=dict(argstr="-usetemp",),
        var_file=dict(argstr="-Rvar %s", extensions=None,),
        verb=dict(argstr="-verb",),
        wherr_file=dict(argstr="-Rwherr %s", extensions=None,),
    )
    inputs = Remlfit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Remlfit_outputs():
    output_map = dict(
        errts_file=dict(extensions=None,),
        fitts_file=dict(extensions=None,),
        glt_file=dict(extensions=None,),
        obeta=dict(extensions=None,),
        obuck=dict(extensions=None,),
        oerrts=dict(extensions=None,),
        ofitts=dict(extensions=None,),
        oglt=dict(extensions=None,),
        out_file=dict(extensions=None,),
        ovar=dict(extensions=None,),
        rbeta_file=dict(extensions=None,),
        var_file=dict(extensions=None,),
        wherr_file=dict(extensions=None,),
    )
    outputs = Remlfit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Slicer


def test_Slicer_inputs():
    input_map = dict(
        all_axial=dict(
            argstr="-A",
            position=10,
            requires=["image_width"],
            xor=("single_slice", "middle_slices", "all_axial", "sample_axial"),
        ),
        args=dict(argstr="%s",),
        colour_map=dict(argstr="-l %s", extensions=None, position=4,),
        dither_edges=dict(argstr="-t", position=7,),
        environ=dict(nohash=True, usedefault=True,),
        image_edges=dict(argstr="%s", extensions=None, position=2,),
        image_width=dict(argstr="%d", position=-2,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        intensity_range=dict(argstr="-i %.3f %.3f", position=5,),
        label_slices=dict(argstr="-L", position=3, usedefault=True,),
        middle_slices=dict(
            argstr="-a",
            position=10,
            xor=("single_slice", "middle_slices", "all_axial", "sample_axial"),
        ),
        nearest_neighbour=dict(argstr="-n", position=8,),
        out_file=dict(
            argstr="%s", extensions=None, genfile=True, hash_files=False, position=-1,
        ),
        output_type=dict(),
        sample_axial=dict(
            argstr="-S %d",
            position=10,
            requires=["image_width"],
            xor=("single_slice", "middle_slices", "all_axial", "sample_axial"),
        ),
        scaling=dict(argstr="-s %f", position=0,),
        show_orientation=dict(argstr="%s", position=9, usedefault=True,),
        single_slice=dict(
            argstr="-%s",
            position=10,
            requires=["slice_number"],
            xor=("single_slice", "middle_slices", "all_axial", "sample_axial"),
        ),
        slice_number=dict(argstr="-%d", position=11,),
        threshold_edges=dict(argstr="-e %.3f", position=6,),
    )
    inputs = Slicer.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Slicer_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Slicer.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import NwarpApply


def test_NwarpApply_inputs():
    input_map = dict(
        ainterp=dict(argstr="-ainterp %s",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-source %s", mandatory=True,),
        interp=dict(argstr="-interp %s", usedefault=True,),
        inv_warp=dict(argstr="-iwarp",),
        master=dict(argstr="-master %s", extensions=None,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_Nwarp",
        ),
        quiet=dict(argstr="-quiet", xor=["verb"],),
        short=dict(argstr="-short",),
        verb=dict(argstr="-verb", xor=["quiet"],),
        warp=dict(argstr="-nwarp %s", mandatory=True,),
    )
    inputs = NwarpApply.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_NwarpApply_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = NwarpApply.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import SphericalAverage


def test_SphericalAverage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        erode=dict(argstr="-erode %d",),
        fname=dict(argstr="%s", mandatory=True, position=-5,),
        hemisphere=dict(argstr="%s", mandatory=True, position=-4,),
        in_average=dict(argstr="%s", genfile=True, position=-2,),
        in_orig=dict(argstr="-orig %s", extensions=None,),
        in_surf=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        out_file=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        subject_id=dict(argstr="-o %s", mandatory=True,),
        subjects_dir=dict(),
        threshold=dict(argstr="-t %.1f",),
        which=dict(argstr="%s", mandatory=True, position=-6,),
    )
    inputs = SphericalAverage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SphericalAverage_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = SphericalAverage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ConvertWarp


def test_ConvertWarp_inputs():
    input_map = dict(
        abswarp=dict(argstr="--abs", xor=["relwarp"],),
        args=dict(argstr="%s",),
        cons_jacobian=dict(argstr="--constrainj",),
        environ=dict(nohash=True, usedefault=True,),
        jacobian_max=dict(argstr="--jmax=%f",),
        jacobian_min=dict(argstr="--jmin=%f",),
        midmat=dict(argstr="--midmat=%s", extensions=None,),
        out_abswarp=dict(argstr="--absout", xor=["out_relwarp"],),
        out_file=dict(
            argstr="--out=%s",
            extensions=None,
            name_source=["reference"],
            name_template="%s_concatwarp",
            output_name="out_file",
            position=-1,
        ),
        out_relwarp=dict(argstr="--relout", xor=["out_abswarp"],),
        output_type=dict(),
        postmat=dict(argstr="--postmat=%s", extensions=None,),
        premat=dict(argstr="--premat=%s", extensions=None,),
        reference=dict(argstr="--ref=%s", extensions=None, mandatory=True, position=1,),
        relwarp=dict(argstr="--rel", xor=["abswarp"],),
        shift_direction=dict(argstr="--shiftdir=%s", requires=["shift_in_file"],),
        shift_in_file=dict(argstr="--shiftmap=%s", extensions=None,),
        warp1=dict(argstr="--warp1=%s", extensions=None,),
        warp2=dict(argstr="--warp2=%s", extensions=None,),
    )
    inputs = ConvertWarp.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ConvertWarp_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ConvertWarp.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Tkregister2


def test_Tkregister2_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fsl_in_matrix=dict(argstr="--fsl %s", extensions=None,),
        fsl_out=dict(argstr="--fslregout %s",),
        fstal=dict(argstr="--fstal", xor=["target_image", "moving_image", "reg_file"],),
        fstarg=dict(argstr="--fstarg", xor=["target_image"],),
        invert_lta_in=dict(requires=["lta_in"],),
        invert_lta_out=dict(argstr="--ltaout-inv", requires=["lta_in"],),
        lta_in=dict(argstr="--lta %s", extensions=None,),
        lta_out=dict(argstr="--ltaout %s",),
        moving_image=dict(argstr="--mov %s", extensions=None, mandatory=True,),
        movscale=dict(argstr="--movscale %f",),
        noedit=dict(argstr="--noedit", usedefault=True,),
        reg_file=dict(
            argstr="--reg %s", extensions=None, mandatory=True, usedefault=True,
        ),
        reg_header=dict(argstr="--regheader",),
        subject_id=dict(argstr="--s %s",),
        subjects_dir=dict(),
        target_image=dict(argstr="--targ %s", extensions=None, xor=["fstarg"],),
        xfm=dict(argstr="--xfm %s", extensions=None,),
    )
    inputs = Tkregister2.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Tkregister2_outputs():
    output_map = dict(
        fsl_file=dict(extensions=None,),
        lta_file=dict(extensions=None,),
        reg_file=dict(extensions=None,),
    )
    outputs = Tkregister2.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..matlab import MatlabCommand


def test_MatlabCommand_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        logfile=dict(argstr="-logfile %s", extensions=None,),
        mfile=dict(usedefault=True,),
        nodesktop=dict(argstr="-nodesktop", nohash=True, usedefault=True,),
        nosplash=dict(argstr="-nosplash", nohash=True, usedefault=True,),
        paths=dict(),
        postscript=dict(usedefault=True,),
        prescript=dict(usedefault=True,),
        script=dict(argstr='-r "%s;exit"', mandatory=True, position=-1,),
        script_file=dict(extensions=None, usedefault=True,),
        single_comp_thread=dict(argstr="-singleCompThread", nohash=True,),
        uses_mcr=dict(
            nohash=True, xor=["nodesktop", "nosplash", "single_comp_thread"],
        ),
    )
    inputs = MatlabCommand.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import SliceTiming


def test_SliceTiming_inputs():
    input_map = dict(
        in_files=dict(copyfile=False, field="scans", mandatory=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        num_slices=dict(field="nslices", mandatory=True,),
        out_prefix=dict(field="prefix", usedefault=True,),
        paths=dict(),
        ref_slice=dict(field="refslice", mandatory=True,),
        slice_order=dict(field="so", mandatory=True,),
        time_acquisition=dict(field="ta", mandatory=True,),
        time_repetition=dict(field="tr", mandatory=True,),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
    )
    inputs = SliceTiming.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SliceTiming_outputs():
    output_map = dict(timecorrected_files=dict(),)
    outputs = SliceTiming.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..metric import MetricResample


def test_MetricResample_inputs():
    input_map = dict(
        area_metrics=dict(argstr="-area-metrics", position=5, xor=["area_surfs"],),
        area_surfs=dict(argstr="-area-surfs", position=5, xor=["area_metrics"],),
        args=dict(argstr="%s",),
        current_area=dict(argstr="%s", extensions=None, position=6,),
        current_sphere=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        largest=dict(argstr="-largest", position=10,),
        method=dict(argstr="%s", mandatory=True, position=3,),
        new_area=dict(argstr="%s", extensions=None, position=7,),
        new_sphere=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        out_file=dict(
            argstr="%s",
            extensions=None,
            keep_extension=True,
            name_source=["new_sphere"],
            name_template="%s.out",
            position=4,
        ),
        roi_metric=dict(argstr="-current-roi %s", extensions=None, position=8,),
        valid_roi_out=dict(argstr="-valid-roi-out", position=9,),
    )
    inputs = MetricResample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MetricResample_outputs():
    output_map = dict(out_file=dict(extensions=None,), roi_file=dict(extensions=None,),)
    outputs = MetricResample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import DWIToDTIEstimation


def test_DWIToDTIEstimation_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        enumeration=dict(argstr="--enumeration %s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume=dict(argstr="%s", extensions=None, position=-3,),
        mask=dict(argstr="--mask %s", extensions=None,),
        outputBaseline=dict(argstr="%s", hash_files=False, position=-1,),
        outputTensor=dict(argstr="%s", hash_files=False, position=-2,),
        shiftNeg=dict(argstr="--shiftNeg ",),
    )
    inputs = DWIToDTIEstimation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DWIToDTIEstimation_outputs():
    output_map = dict(
        outputBaseline=dict(extensions=None, position=-1,),
        outputTensor=dict(extensions=None, position=-2,),
    )
    outputs = DWIToDTIEstimation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ComputeTDI


def test_ComputeTDI_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        contrast=dict(argstr="-constrast %s",),
        data_type=dict(argstr="-datatype %s",),
        dixel=dict(argstr="-dixel %s", extensions=None,),
        ends_only=dict(argstr="-ends_only",),
        environ=dict(nohash=True, usedefault=True,),
        fwhm_tck=dict(argstr="-fwhm_tck %f",),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        in_map=dict(argstr="-image %s", extensions=None,),
        map_zero=dict(argstr="-map_zero",),
        max_tod=dict(argstr="-tod %d",),
        nthreads=dict(argstr="-nthreads %d", nohash=True,),
        out_file=dict(argstr="%s", extensions=None, position=-1, usedefault=True,),
        precise=dict(argstr="-precise",),
        reference=dict(argstr="-template %s", extensions=None,),
        stat_tck=dict(argstr="-stat_tck %s",),
        stat_vox=dict(argstr="-stat_vox %s",),
        tck_weights=dict(argstr="-tck_weights_in %s", extensions=None,),
        upsample=dict(argstr="-upsample %d",),
        use_dec=dict(argstr="-dec",),
        vox_size=dict(argstr="-vox %s", sep=",",),
    )
    inputs = ComputeTDI.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ComputeTDI_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ComputeTDI.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dcm2nii import Dcm2nii


def test_Dcm2nii_inputs():
    input_map = dict(
        anonymize=dict(argstr="-a", usedefault=True,),
        args=dict(argstr="%s",),
        collapse_folders=dict(argstr="-c", usedefault=True,),
        config_file=dict(argstr="-b %s", extensions=None, genfile=True,),
        convert_all_pars=dict(argstr="-v", usedefault=True,),
        date_in_filename=dict(argstr="-d", usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        events_in_filename=dict(argstr="-e", usedefault=True,),
        gzip_output=dict(argstr="-g", usedefault=True,),
        id_in_filename=dict(argstr="-i", usedefault=True,),
        nii_output=dict(argstr="-n", usedefault=True,),
        output_dir=dict(argstr="-o %s", genfile=True,),
        protocol_in_filename=dict(argstr="-p", usedefault=True,),
        reorient=dict(argstr="-r",),
        reorient_and_crop=dict(argstr="-x", usedefault=True,),
        source_dir=dict(
            argstr="%s", mandatory=True, position=-1, xor=["source_names"],
        ),
        source_in_filename=dict(argstr="-f", usedefault=True,),
        source_names=dict(
            argstr="%s",
            copyfile=False,
            mandatory=True,
            position=-1,
            xor=["source_dir"],
        ),
        spm_analyze=dict(argstr="-s", xor=["nii_output"],),
    )
    inputs = Dcm2nii.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Dcm2nii_outputs():
    output_map = dict(
        bvals=dict(),
        bvecs=dict(),
        converted_files=dict(),
        reoriented_and_cropped_files=dict(),
        reoriented_files=dict(),
    )
    outputs = Dcm2nii.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..meshfix import MeshFix


def test_MeshFix_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cut_inner=dict(argstr="--cut-inner %d",),
        cut_outer=dict(argstr="--cut-outer %d",),
        decouple_inin=dict(argstr="--decouple-inin %d",),
        decouple_outin=dict(argstr="--decouple-outin %d",),
        decouple_outout=dict(argstr="--decouple-outout %d",),
        dilation=dict(argstr="--dilate %d",),
        dont_clean=dict(argstr="--no-clean",),
        environ=dict(nohash=True, usedefault=True,),
        epsilon_angle=dict(argstr="-a %f",),
        finetuning_distance=dict(
            argstr="%f", position=-2, requires=["finetuning_substeps"],
        ),
        finetuning_inwards=dict(
            argstr="--fineTuneIn ",
            position=-3,
            requires=["finetuning_distance", "finetuning_substeps"],
        ),
        finetuning_outwards=dict(
            argstr="--fineTuneOut ",
            position=-3,
            requires=["finetuning_distance", "finetuning_substeps"],
            xor=["finetuning_inwards"],
        ),
        finetuning_substeps=dict(
            argstr="%d", position=-1, requires=["finetuning_distance"],
        ),
        in_file1=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        in_file2=dict(argstr="%s", extensions=None, position=2,),
        join_closest_components=dict(argstr="-jc", xor=["join_closest_components"],),
        join_overlapping_largest_components=dict(
            argstr="-j", xor=["join_closest_components"],
        ),
        laplacian_smoothing_steps=dict(argstr="--smooth %d",),
        number_of_biggest_shells=dict(argstr="--shells %d",),
        out_filename=dict(argstr="-o %s", extensions=None, genfile=True,),
        output_type=dict(usedefault=True,),
        quiet_mode=dict(argstr="-q",),
        remove_handles=dict(argstr="--remove-handles",),
        save_as_freesurfer_mesh=dict(
            argstr="--fsmesh", xor=["save_as_vrml", "save_as_stl"],
        ),
        save_as_stl=dict(
            argstr="--stl", xor=["save_as_vrml", "save_as_freesurfer_mesh"],
        ),
        save_as_vrml=dict(
            argstr="--wrl", xor=["save_as_stl", "save_as_freesurfer_mesh"],
        ),
        set_intersections_to_one=dict(argstr="--intersect",),
        uniform_remeshing_steps=dict(
            argstr="-u %d", requires=["uniform_remeshing_vertices"],
        ),
        uniform_remeshing_vertices=dict(
            argstr="--vertices %d", requires=["uniform_remeshing_steps"],
        ),
        x_shift=dict(argstr="--smooth %d",),
    )
    inputs = MeshFix.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MeshFix_outputs():
    output_map = dict(mesh_file=dict(extensions=None,),)
    outputs = MeshFix.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..visualization import CreateTiledMosaic


def test_CreateTiledMosaic_inputs():
    input_map = dict(
        alpha_value=dict(argstr="-a %.2f",),
        args=dict(argstr="%s",),
        direction=dict(argstr="-d %d",),
        environ=dict(nohash=True, usedefault=True,),
        flip_slice=dict(argstr="-f %s",),
        input_image=dict(argstr="-i %s", extensions=None, mandatory=True,),
        mask_image=dict(argstr="-x %s", extensions=None,),
        num_threads=dict(nohash=True, usedefault=True,),
        output_image=dict(argstr="-o %s", usedefault=True,),
        pad_or_crop=dict(argstr="-p %s",),
        permute_axes=dict(argstr="-g",),
        rgb_image=dict(argstr="-r %s", extensions=None, mandatory=True,),
        slices=dict(argstr="-s %s",),
        tile_geometry=dict(argstr="-t %s",),
    )
    inputs = CreateTiledMosaic.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CreateTiledMosaic_outputs():
    output_map = dict(output_image=dict(extensions=None,),)
    outputs = CreateTiledMosaic.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import TalairachQC


def test_TalairachQC_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        log_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        subjects_dir=dict(),
    )
    inputs = TalairachQC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TalairachQC_outputs():
    output_map = dict(log_file=dict(extensions=None, usedefault=True,),)
    outputs = TalairachQC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..lesions import FillLesions


def test_FillLesions_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bin_mask=dict(argstr="-mask %s", extensions=None,),
        cwf=dict(argstr="-cwf %f",),
        debug=dict(argstr="-debug",),
        environ=dict(nohash=True, usedefault=True,),
        in_dilation=dict(argstr="-dil %d",),
        in_file=dict(argstr="-i %s", extensions=None, mandatory=True, position=1,),
        lesion_mask=dict(argstr="-l %s", extensions=None, mandatory=True, position=2,),
        match=dict(argstr="-match %f",),
        other=dict(argstr="-other",),
        out_datatype=dict(argstr="-odt %s",),
        out_file=dict(
            argstr="-o %s",
            extensions=None,
            name_source=["in_file"],
            name_template="%s_lesions_filled.nii.gz",
            position=3,
        ),
        search=dict(argstr="-search %f",),
        size=dict(argstr="-size %d",),
        smooth=dict(argstr="-smo %f",),
        use_2d=dict(argstr="-2D",),
        verbose=dict(argstr="-v",),
    )
    inputs = FillLesions.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FillLesions_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = FillLesions.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Segment


def test_Segment_inputs():
    input_map = dict(
        affine_regularization=dict(field="opts.regtype",),
        bias_fwhm=dict(field="opts.biasfwhm",),
        bias_regularization=dict(field="opts.biasreg",),
        clean_masks=dict(field="output.cleanup",),
        csf_output_type=dict(field="output.CSF",),
        data=dict(copyfile=False, field="data", mandatory=True,),
        gaussians_per_class=dict(field="opts.ngaus",),
        gm_output_type=dict(field="output.GM",),
        mask_image=dict(extensions=None, field="opts.msk",),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        paths=dict(),
        sampling_distance=dict(field="opts.samp",),
        save_bias_corrected=dict(field="output.biascor",),
        tissue_prob_maps=dict(field="opts.tpm",),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
        warp_frequency_cutoff=dict(field="opts.warpco",),
        warping_regularization=dict(field="opts.warpreg",),
        wm_output_type=dict(field="output.WM",),
    )
    inputs = Segment.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Segment_outputs():
    output_map = dict(
        bias_corrected_image=dict(extensions=None,),
        inverse_transformation_mat=dict(extensions=None,),
        modulated_csf_image=dict(extensions=None,),
        modulated_gm_image=dict(extensions=None,),
        modulated_input_image=dict(
            deprecated="0.10", extensions=None, new_name="bias_corrected_image",
        ),
        modulated_wm_image=dict(extensions=None,),
        native_csf_image=dict(extensions=None,),
        native_gm_image=dict(extensions=None,),
        native_wm_image=dict(extensions=None,),
        normalized_csf_image=dict(extensions=None,),
        normalized_gm_image=dict(extensions=None,),
        normalized_wm_image=dict(extensions=None,),
        transformation_mat=dict(extensions=None,),
    )
    outputs = Segment.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..regutils import RegMeasure


def test_RegMeasure_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        flo_file=dict(argstr="-flo %s", extensions=None, mandatory=True,),
        measure_type=dict(argstr="-%s", mandatory=True,),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        out_file=dict(
            argstr="-out %s",
            extensions=None,
            name_source=["flo_file"],
            name_template="%s",
        ),
        ref_file=dict(argstr="-ref %s", extensions=None, mandatory=True,),
    )
    inputs = RegMeasure.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegMeasure_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = RegMeasure.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import PlotMotionParams


def test_PlotMotionParams_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", mandatory=True, position=1,),
        in_source=dict(mandatory=True,),
        out_file=dict(argstr="-o %s", extensions=None, genfile=True, hash_files=False,),
        output_type=dict(),
        plot_size=dict(argstr="%s",),
        plot_type=dict(argstr="%s", mandatory=True,),
    )
    inputs = PlotMotionParams.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PlotMotionParams_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = PlotMotionParams.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..registration import MRICoreg


def test_MRICoreg_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        brute_force_limit=dict(argstr="--bf-lim %g", xor=["no_brute_force"],),
        brute_force_samples=dict(argstr="--bf-nsamp %d", xor=["no_brute_force"],),
        conform_reference=dict(argstr="--conf-ref",),
        dof=dict(argstr="--dof %d",),
        environ=dict(nohash=True, usedefault=True,),
        ftol=dict(argstr="--ftol %e",),
        initial_rotation=dict(argstr="--rot %g %g %g",),
        initial_scale=dict(argstr="--scale %g %g %g",),
        initial_shear=dict(argstr="--shear %g %g %g",),
        initial_translation=dict(argstr="--trans %g %g %g",),
        linmintol=dict(argstr="--linmintol %e",),
        max_iters=dict(argstr="--nitersmax %d",),
        no_brute_force=dict(argstr="--no-bf",),
        no_coord_dithering=dict(argstr="--no-coord-dither",),
        no_cras0=dict(argstr="--no-cras0",),
        no_intensity_dithering=dict(argstr="--no-intensity-dither",),
        no_smooth=dict(argstr="--no-smooth",),
        num_threads=dict(argstr="--threads %d",),
        out_lta_file=dict(argstr="--lta %s", usedefault=True,),
        out_params_file=dict(argstr="--params %s",),
        out_reg_file=dict(argstr="--regdat %s",),
        ref_fwhm=dict(argstr="--ref-fwhm",),
        reference_file=dict(
            argstr="--ref %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            xor=["subject_id"],
        ),
        reference_mask=dict(argstr="--ref-mask %s", position=2,),
        saturation_threshold=dict(argstr="--sat %g",),
        sep=dict(argstr="--sep %s...",),
        source_file=dict(
            argstr="--mov %s", copyfile=False, extensions=None, mandatory=True,
        ),
        source_mask=dict(argstr="--mov-mask",),
        source_oob=dict(argstr="--mov-oob",),
        subject_id=dict(
            argstr="--s %s",
            mandatory=True,
            position=1,
            requires=["subjects_dir"],
            xor=["reference_file"],
        ),
        subjects_dir=dict(argstr="--sd %s",),
    )
    inputs = MRICoreg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRICoreg_outputs():
    output_map = dict(
        out_lta_file=dict(extensions=None,),
        out_params_file=dict(extensions=None,),
        out_reg_file=dict(extensions=None,),
    )
    outputs = MRICoreg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import Shredder


def test_Shredder_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        chunksize=dict(argstr="%d", position=2, units="NA",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="< %s", extensions=None, mandatory=True, position=-2,),
        offset=dict(argstr="%d", position=1, units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        space=dict(argstr="%d", position=3, units="NA",),
    )
    inputs = Shredder.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Shredder_outputs():
    output_map = dict(shredded=dict(extensions=None,),)
    outputs = Shredder.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import SimilarityIndex


def test_SimilarityIndex_inputs():
    input_map = dict(
        ANNContinuousVolume=dict(argstr="--ANNContinuousVolume %s", extensions=None,),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputManualVolume=dict(argstr="--inputManualVolume %s", extensions=None,),
        outputCSVFilename=dict(argstr="--outputCSVFilename %s", extensions=None,),
        thresholdInterval=dict(argstr="--thresholdInterval %f",),
    )
    inputs = SimilarityIndex.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SimilarityIndex_outputs():
    output_map = dict()
    outputs = SimilarityIndex.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import EMSegmentCommandLine


def test_EMSegmentCommandLine_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        atlasVolumeFileNames=dict(argstr="--atlasVolumeFileNames %s...",),
        disableCompression=dict(argstr="--disableCompression ",),
        disableMultithreading=dict(argstr="--disableMultithreading %d",),
        dontUpdateIntermediateData=dict(argstr="--dontUpdateIntermediateData %d",),
        dontWriteResults=dict(argstr="--dontWriteResults ",),
        environ=dict(nohash=True, usedefault=True,),
        generateEmptyMRMLSceneAndQuit=dict(
            argstr="--generateEmptyMRMLSceneAndQuit %s", hash_files=False,
        ),
        intermediateResultsDirectory=dict(argstr="--intermediateResultsDirectory %s",),
        keepTempFiles=dict(argstr="--keepTempFiles ",),
        loadAtlasNonCentered=dict(argstr="--loadAtlasNonCentered ",),
        loadTargetCentered=dict(argstr="--loadTargetCentered ",),
        mrmlSceneFileName=dict(argstr="--mrmlSceneFileName %s", extensions=None,),
        parametersMRMLNodeName=dict(argstr="--parametersMRMLNodeName %s",),
        registrationAffineType=dict(argstr="--registrationAffineType %d",),
        registrationDeformableType=dict(argstr="--registrationDeformableType %d",),
        registrationPackage=dict(argstr="--registrationPackage %s",),
        resultMRMLSceneFileName=dict(
            argstr="--resultMRMLSceneFileName %s", hash_files=False,
        ),
        resultStandardVolumeFileName=dict(
            argstr="--resultStandardVolumeFileName %s", extensions=None,
        ),
        resultVolumeFileName=dict(
            argstr="--resultVolumeFileName %s", hash_files=False,
        ),
        targetVolumeFileNames=dict(argstr="--targetVolumeFileNames %s...",),
        taskPreProcessingSetting=dict(argstr="--taskPreProcessingSetting %s",),
        verbose=dict(argstr="--verbose ",),
    )
    inputs = EMSegmentCommandLine.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_EMSegmentCommandLine_outputs():
    output_map = dict(
        generateEmptyMRMLSceneAndQuit=dict(extensions=None,),
        resultMRMLSceneFileName=dict(extensions=None,),
        resultVolumeFileName=dict(extensions=None,),
    )
    outputs = EMSegmentCommandLine.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import ReconAll


def test_ReconAll_inputs():
    input_map = dict(
        FLAIR_file=dict(argstr="-FLAIR %s", extensions=None, min_ver="5.3.0",),
        T1_files=dict(argstr="-i %s...",),
        T2_file=dict(argstr="-T2 %s", extensions=None, min_ver="5.3.0",),
        args=dict(argstr="%s",),
        big_ventricles=dict(argstr="-bigventricles",),
        brainstem=dict(argstr="-brainstem-structures",),
        directive=dict(argstr="-%s", position=0, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        expert=dict(argstr="-expert %s", extensions=None,),
        flags=dict(argstr="%s",),
        hemi=dict(argstr="-hemi %s",),
        hippocampal_subfields_T1=dict(
            argstr="-hippocampal-subfields-T1", min_ver="6.0.0",
        ),
        hippocampal_subfields_T2=dict(
            argstr="-hippocampal-subfields-T2 %s %s", min_ver="6.0.0",
        ),
        hires=dict(argstr="-hires", min_ver="6.0.0",),
        mprage=dict(argstr="-mprage",),
        mri_aparc2aseg=dict(xor=["expert"],),
        mri_ca_label=dict(xor=["expert"],),
        mri_ca_normalize=dict(xor=["expert"],),
        mri_ca_register=dict(xor=["expert"],),
        mri_edit_wm_with_aseg=dict(xor=["expert"],),
        mri_em_register=dict(xor=["expert"],),
        mri_fill=dict(xor=["expert"],),
        mri_mask=dict(xor=["expert"],),
        mri_normalize=dict(xor=["expert"],),
        mri_pretess=dict(xor=["expert"],),
        mri_remove_neck=dict(xor=["expert"],),
        mri_segment=dict(xor=["expert"],),
        mri_segstats=dict(xor=["expert"],),
        mri_tessellate=dict(xor=["expert"],),
        mri_watershed=dict(xor=["expert"],),
        mris_anatomical_stats=dict(xor=["expert"],),
        mris_ca_label=dict(xor=["expert"],),
        mris_fix_topology=dict(xor=["expert"],),
        mris_inflate=dict(xor=["expert"],),
        mris_make_surfaces=dict(xor=["expert"],),
        mris_register=dict(xor=["expert"],),
        mris_smooth=dict(xor=["expert"],),
        mris_sphere=dict(xor=["expert"],),
        mris_surf2vol=dict(xor=["expert"],),
        mrisp_paint=dict(xor=["expert"],),
        openmp=dict(argstr="-openmp %d",),
        parallel=dict(argstr="-parallel",),
        subject_id=dict(argstr="-subjid %s", usedefault=True,),
        subjects_dir=dict(argstr="-sd %s", genfile=True, hash_files=False,),
        talairach=dict(xor=["expert"],),
        use_FLAIR=dict(argstr="-FLAIRpial", min_ver="5.3.0", xor=["use_T2"],),
        use_T2=dict(argstr="-T2pial", min_ver="5.3.0", xor=["use_FLAIR"],),
        xopts=dict(argstr="-xopts-%s",),
    )
    inputs = ReconAll.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ReconAll_outputs():
    output_map = dict(
        BA_stats=dict(altkey="BA", loc="stats",),
        T1=dict(extensions=None, loc="mri",),
        annot=dict(altkey="*annot", loc="label",),
        aparc_a2009s_stats=dict(altkey="aparc.a2009s", loc="stats",),
        aparc_aseg=dict(altkey="aparc*aseg", loc="mri",),
        aparc_stats=dict(altkey="aparc", loc="stats",),
        area_pial=dict(altkey="area.pial", loc="surf",),
        aseg=dict(extensions=None, loc="mri",),
        aseg_stats=dict(altkey="aseg", loc="stats",),
        avg_curv=dict(loc="surf",),
        brain=dict(extensions=None, loc="mri",),
        brainmask=dict(extensions=None, loc="mri",),
        curv=dict(loc="surf",),
        curv_pial=dict(altkey="curv.pial", loc="surf",),
        curv_stats=dict(altkey="curv", loc="stats",),
        entorhinal_exvivo_stats=dict(altkey="entorhinal_exvivo", loc="stats",),
        filled=dict(extensions=None, loc="mri",),
        graymid=dict(altkey=["graymid", "midthickness"], loc="surf",),
        inflated=dict(loc="surf",),
        jacobian_white=dict(loc="surf",),
        label=dict(altkey="*label", loc="label",),
        norm=dict(extensions=None, loc="mri",),
        nu=dict(extensions=None, loc="mri",),
        orig=dict(extensions=None, loc="mri",),
        pial=dict(loc="surf",),
        rawavg=dict(extensions=None, loc="mri",),
        ribbon=dict(altkey="*ribbon", loc="mri",),
        smoothwm=dict(loc="surf",),
        sphere=dict(loc="surf",),
        sphere_reg=dict(altkey="sphere.reg", loc="surf",),
        subject_id=dict(),
        subjects_dir=dict(),
        sulc=dict(loc="surf",),
        thickness=dict(loc="surf",),
        volume=dict(loc="surf",),
        white=dict(loc="surf",),
        wm=dict(extensions=None, loc="mri",),
        wmparc=dict(extensions=None, loc="mri",),
        wmparc_stats=dict(altkey="wmparc", loc="stats",),
    )
    outputs = ReconAll.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import MedicAlgorithmMipavReorient


def test_MedicAlgorithmMipavReorient_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inInterpolation=dict(argstr="--inInterpolation %s",),
        inNew=dict(argstr="--inNew %s",),
        inResolution=dict(argstr="--inResolution %s",),
        inSource=dict(argstr="--inSource %s", sep=";",),
        inTemplate=dict(argstr="--inTemplate %s", extensions=None,),
        inUser=dict(argstr="--inUser %s",),
        inUser2=dict(argstr="--inUser2 %s",),
        inUser3=dict(argstr="--inUser3 %s",),
        inUser4=dict(argstr="--inUser4 %s",),
        null=dict(argstr="--null %s",),
        outReoriented=dict(argstr="--outReoriented %s", sep=";",),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = MedicAlgorithmMipavReorient.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MedicAlgorithmMipavReorient_outputs():
    output_map = dict()
    outputs = MedicAlgorithmMipavReorient.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..featuredetection import GenerateSummedGradientImage


def test_GenerateSummedGradientImage_inputs():
    input_map = dict(
        MaximumGradient=dict(argstr="--MaximumGradient ",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputVolume1=dict(argstr="--inputVolume1 %s", extensions=None,),
        inputVolume2=dict(argstr="--inputVolume2 %s", extensions=None,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputFileName=dict(argstr="--outputFileName %s", hash_files=False,),
    )
    inputs = GenerateSummedGradientImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GenerateSummedGradientImage_outputs():
    output_map = dict(outputFileName=dict(extensions=None,),)
    outputs = GenerateSummedGradientImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..convert import NIfTIDT2Camino


def test_NIfTIDT2Camino_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bgmask=dict(argstr="-bgmask %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-inputfile %s", extensions=None, mandatory=True, position=1,
        ),
        lns0_file=dict(argstr="-lns0 %s", extensions=None,),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        s0_file=dict(argstr="-s0 %s", extensions=None,),
        scaleinter=dict(argstr="-scaleinter %s",),
        scaleslope=dict(argstr="-scaleslope %s",),
        uppertriangular=dict(argstr="-uppertriangular %s",),
    )
    inputs = NIfTIDT2Camino.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_NIfTIDT2Camino_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = NIfTIDT2Camino.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import dtiaverage


def test_dtiaverage_inputs():
    input_map = dict(
        DTI_double=dict(argstr="--DTI_double ",),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputs=dict(argstr="--inputs %s...",),
        tensor_output=dict(argstr="--tensor_output %s", hash_files=False,),
        verbose=dict(argstr="--verbose ",),
    )
    inputs = dtiaverage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_dtiaverage_outputs():
    output_map = dict(tensor_output=dict(extensions=None,),)
    outputs = dtiaverage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import BinThreshTask


def test_BinThreshTask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=0,),
        inside_value=dict(argstr="%g", mandatory=True, position=4, usedefault=True,),
        lower_bound=dict(argstr="%g", mandatory=True, position=2, usedefault=True,),
        out_file=dict(
            argstr="%s",
            extensions=None,
            keep_extension=True,
            name_source="in_file",
            name_template="%s_thrbin",
            position=1,
        ),
        outside_value=dict(argstr="%g", mandatory=True, position=5, usedefault=True,),
        upper_bound=dict(argstr="%g", mandatory=True, position=3, usedefault=True,),
    )
    inputs = BinThreshTask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BinThreshTask_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = BinThreshTask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..tensors import Directions2Amplitude


def test_Directions2Amplitude_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        display_debug=dict(argstr="-debug",),
        display_info=dict(argstr="-info",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        num_peaks=dict(argstr="-num %s",),
        out_file=dict(
            argstr="%s",
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=["in_file"],
            name_template="%s_amplitudes.mif",
            position=-1,
        ),
        peak_directions=dict(argstr="-direction %s", sep=" ",),
        peaks_image=dict(argstr="-peaks %s", extensions=None,),
        quiet_display=dict(argstr="-quiet",),
    )
    inputs = Directions2Amplitude.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Directions2Amplitude_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Directions2Amplitude.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import To3D


def test_To3D_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        assumemosaic=dict(argstr="-assume_dicom_mosaic",),
        datatype=dict(argstr="-datum %s",),
        environ=dict(nohash=True, usedefault=True,),
        filetype=dict(argstr="-%s",),
        funcparams=dict(argstr="-time:zt %s alt+z2",),
        in_folder=dict(argstr="%s/*.dcm", mandatory=True, position=-1,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source=["in_folder"],
            name_template="%s",
        ),
        outputtype=dict(),
        skipoutliers=dict(argstr="-skip_outliers",),
    )
    inputs = To3D.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_To3D_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = To3D.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import JistBrainMgdmSegmentation


def test_JistBrainMgdmSegmentation_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inAdjust=dict(argstr="--inAdjust %s",),
        inAtlas=dict(argstr="--inAtlas %s", extensions=None,),
        inCompute=dict(argstr="--inCompute %s",),
        inCurvature=dict(argstr="--inCurvature %f",),
        inData=dict(argstr="--inData %f",),
        inFLAIR=dict(argstr="--inFLAIR %s", extensions=None,),
        inMP2RAGE=dict(argstr="--inMP2RAGE %s", extensions=None,),
        inMP2RAGE2=dict(argstr="--inMP2RAGE2 %s", extensions=None,),
        inMPRAGE=dict(argstr="--inMPRAGE %s", extensions=None,),
        inMax=dict(argstr="--inMax %d",),
        inMin=dict(argstr="--inMin %f",),
        inOutput=dict(argstr="--inOutput %s",),
        inPV=dict(argstr="--inPV %s", extensions=None,),
        inPosterior=dict(argstr="--inPosterior %f",),
        inSteps=dict(argstr="--inSteps %d",),
        inTopology=dict(argstr="--inTopology %s",),
        null=dict(argstr="--null %s",),
        outLevelset=dict(argstr="--outLevelset %s", hash_files=False,),
        outPosterior2=dict(argstr="--outPosterior2 %s", hash_files=False,),
        outPosterior3=dict(argstr="--outPosterior3 %s", hash_files=False,),
        outSegmented=dict(argstr="--outSegmented %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = JistBrainMgdmSegmentation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JistBrainMgdmSegmentation_outputs():
    output_map = dict(
        outLevelset=dict(extensions=None,),
        outPosterior2=dict(extensions=None,),
        outPosterior3=dict(extensions=None,),
        outSegmented=dict(extensions=None,),
    )
    outputs = JistBrainMgdmSegmentation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import ParseDICOMDir


def test_ParseDICOMDir_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dicom_dir=dict(argstr="--d %s", mandatory=True,),
        dicom_info_file=dict(argstr="--o %s", extensions=None, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        sortbyrun=dict(argstr="--sortbyrun",),
        subjects_dir=dict(),
        summarize=dict(argstr="--summarize",),
    )
    inputs = ParseDICOMDir.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ParseDICOMDir_outputs():
    output_map = dict(dicom_info_file=dict(extensions=None,),)
    outputs = ParseDICOMDir.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import PRELUDE


def test_PRELUDE_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        complex_phase_file=dict(
            argstr="--complex=%s",
            extensions=None,
            mandatory=True,
            xor=["magnitude_file", "phase_file"],
        ),
        end=dict(argstr="--end=%d",),
        environ=dict(nohash=True, usedefault=True,),
        label_file=dict(argstr="--labels=%s", extensions=None, hash_files=False,),
        labelprocess2d=dict(argstr="--labelslices",),
        magnitude_file=dict(
            argstr="--abs=%s",
            extensions=None,
            mandatory=True,
            xor=["complex_phase_file"],
        ),
        mask_file=dict(argstr="--mask=%s", extensions=None,),
        num_partitions=dict(argstr="--numphasesplit=%d",),
        output_type=dict(),
        phase_file=dict(
            argstr="--phase=%s",
            extensions=None,
            mandatory=True,
            xor=["complex_phase_file"],
        ),
        process2d=dict(argstr="--slices", xor=["labelprocess2d"],),
        process3d=dict(argstr="--force3D", xor=["labelprocess2d", "process2d"],),
        rawphase_file=dict(argstr="--rawphase=%s", extensions=None, hash_files=False,),
        removeramps=dict(argstr="--removeramps",),
        savemask_file=dict(argstr="--savemask=%s", extensions=None, hash_files=False,),
        start=dict(argstr="--start=%d",),
        threshold=dict(argstr="--thresh=%.10f",),
        unwrapped_phase_file=dict(
            argstr="--unwrap=%s", extensions=None, genfile=True, hash_files=False,
        ),
    )
    inputs = PRELUDE.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PRELUDE_outputs():
    output_map = dict(unwrapped_phase_file=dict(extensions=None,),)
    outputs = PRELUDE.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BRAINSABC


def test_BRAINSABC_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        atlasDefinition=dict(argstr="--atlasDefinition %s", extensions=None,),
        atlasToSubjectInitialTransform=dict(
            argstr="--atlasToSubjectInitialTransform %s", hash_files=False,
        ),
        atlasToSubjectTransform=dict(
            argstr="--atlasToSubjectTransform %s", hash_files=False,
        ),
        atlasToSubjectTransformType=dict(argstr="--atlasToSubjectTransformType %s",),
        atlasWarpingOff=dict(argstr="--atlasWarpingOff ",),
        debuglevel=dict(argstr="--debuglevel %d",),
        defaultSuffix=dict(argstr="--defaultSuffix %s",),
        environ=dict(nohash=True, usedefault=True,),
        filterIteration=dict(argstr="--filterIteration %d",),
        filterMethod=dict(argstr="--filterMethod %s",),
        filterTimeStep=dict(argstr="--filterTimeStep %f",),
        gridSize=dict(argstr="--gridSize %s", sep=",",),
        implicitOutputs=dict(argstr="--implicitOutputs %s...", hash_files=False,),
        inputVolumeTypes=dict(argstr="--inputVolumeTypes %s", sep=",",),
        inputVolumes=dict(argstr="--inputVolumes %s...",),
        interpolationMode=dict(argstr="--interpolationMode %s",),
        maxBiasDegree=dict(argstr="--maxBiasDegree %d",),
        maxIterations=dict(argstr="--maxIterations %d",),
        medianFilterSize=dict(argstr="--medianFilterSize %s", sep=",",),
        numberOfSubSamplesInEachPlugArea=dict(
            argstr="--numberOfSubSamplesInEachPlugArea %s", sep=",",
        ),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputDir=dict(argstr="--outputDir %s", hash_files=False,),
        outputDirtyLabels=dict(argstr="--outputDirtyLabels %s", hash_files=False,),
        outputFormat=dict(argstr="--outputFormat %s",),
        outputLabels=dict(argstr="--outputLabels %s", hash_files=False,),
        outputVolumes=dict(argstr="--outputVolumes %s...", hash_files=False,),
        posteriorTemplate=dict(argstr="--posteriorTemplate %s",),
        purePlugsThreshold=dict(argstr="--purePlugsThreshold %f",),
        restoreState=dict(argstr="--restoreState %s", extensions=None,),
        saveState=dict(argstr="--saveState %s", hash_files=False,),
        subjectIntermodeTransformType=dict(
            argstr="--subjectIntermodeTransformType %s",
        ),
        useKNN=dict(argstr="--useKNN ",),
        writeLess=dict(argstr="--writeLess ",),
    )
    inputs = BRAINSABC.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSABC_outputs():
    output_map = dict(
        atlasToSubjectInitialTransform=dict(extensions=None,),
        atlasToSubjectTransform=dict(extensions=None,),
        implicitOutputs=dict(),
        outputDir=dict(),
        outputDirtyLabels=dict(extensions=None,),
        outputLabels=dict(extensions=None,),
        outputVolumes=dict(),
        saveState=dict(extensions=None,),
    )
    outputs = BRAINSABC.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..resampling import WarpImageMultiTransform


def test_WarpImageMultiTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="%d", position=1, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        input_image=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        invert_affine=dict(),
        num_threads=dict(nohash=True, usedefault=True,),
        out_postfix=dict(
            extensions=None, hash_files=False, usedefault=True, xor=["output_image"],
        ),
        output_image=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            position=3,
            xor=["out_postfix"],
        ),
        reference_image=dict(argstr="-R %s", extensions=None, xor=["tightest_box"],),
        reslice_by_header=dict(argstr="--reslice-by-header",),
        tightest_box=dict(argstr="--tightest-bounding-box", xor=["reference_image"],),
        transformation_series=dict(argstr="%s", mandatory=True, position=-1,),
        use_bspline=dict(argstr="--use-BSpline",),
        use_nearest=dict(argstr="--use-NN",),
    )
    inputs = WarpImageMultiTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_WarpImageMultiTransform_outputs():
    output_map = dict(output_image=dict(extensions=None,),)
    outputs = WarpImageMultiTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Smooth


def test_Smooth_inputs():
    input_map = dict(
        data_type=dict(field="dtype",),
        fwhm=dict(field="fwhm",),
        implicit_masking=dict(field="im",),
        in_files=dict(copyfile=False, field="data", mandatory=True,),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True,),
        out_prefix=dict(field="prefix", usedefault=True,),
        paths=dict(),
        use_mcr=dict(),
        use_v8struct=dict(min_ver="8", usedefault=True,),
    )
    inputs = Smooth.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Smooth_outputs():
    output_map = dict(smoothed_files=dict(),)
    outputs = Smooth.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import NwarpCat


def test_NwarpCat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        expad=dict(argstr="-expad %d",),
        in_files=dict(argstr="%s", mandatory=True, position=-1,),
        interp=dict(argstr="-interp %s", usedefault=True,),
        inv_warp=dict(argstr="-iwarp",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_files",
            name_template="%s_NwarpCat",
        ),
        outputtype=dict(),
        space=dict(argstr="-space %s",),
        verb=dict(argstr="-verb",),
    )
    inputs = NwarpCat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_NwarpCat_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = NwarpCat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Automask


def test_Automask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        brain_file=dict(
            argstr="-apply_prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_masked",
        ),
        clfrac=dict(argstr="-clfrac %s",),
        dilate=dict(argstr="-dilate %s",),
        environ=dict(nohash=True, usedefault=True,),
        erode=dict(argstr="-erode %s",),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_mask",
        ),
        outputtype=dict(),
    )
    inputs = Automask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Automask_outputs():
    output_map = dict(
        brain_file=dict(extensions=None,), out_file=dict(extensions=None,),
    )
    outputs = Automask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import GCOR


def test_GCOR_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        mask=dict(argstr="-mask %s", copyfile=False, extensions=None,),
        nfirst=dict(argstr="-nfirst %d",),
        no_demean=dict(argstr="-no_demean",),
    )
    inputs = GCOR.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GCOR_outputs():
    output_map = dict(out=dict(),)
    outputs = GCOR.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..epi import PrepareFieldmap


def test_PrepareFieldmap_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        delta_TE=dict(argstr="%f", mandatory=True, position=-2, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_magnitude=dict(argstr="%s", extensions=None, mandatory=True, position=3,),
        in_phase=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        nocheck=dict(argstr="--nocheck", position=-1, usedefault=True,),
        out_fieldmap=dict(argstr="%s", extensions=None, position=4,),
        output_type=dict(),
        scanner=dict(argstr="%s", position=1, usedefault=True,),
    )
    inputs = PrepareFieldmap.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_PrepareFieldmap_outputs():
    output_map = dict(out_fieldmap=dict(extensions=None,),)
    outputs = PrepareFieldmap.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Hist


def test_Hist_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bin_width=dict(argstr="-binwidth %f",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=1,
        ),
        mask=dict(argstr="-mask %s", extensions=None,),
        max_value=dict(argstr="-max %f",),
        min_value=dict(argstr="-min %f",),
        nbin=dict(argstr="-nbin %d",),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            keep_extension=False,
            name_source=["in_file"],
            name_template="%s_hist",
        ),
        out_show=dict(
            argstr="> %s",
            extensions=None,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_hist.out",
            position=-1,
        ),
        showhist=dict(argstr="-showhist", usedefault=True,),
    )
    inputs = Hist.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Hist_outputs():
    output_map = dict(out_file=dict(extensions=None,), out_show=dict(extensions=None,),)
    outputs = Hist.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..io import XNATSink


def test_XNATSink_inputs():
    input_map = dict(
        _outputs=dict(usedefault=True,),
        assessor_id=dict(xor=["reconstruction_id"],),
        cache_dir=dict(),
        config=dict(extensions=None, mandatory=True, xor=["server"],),
        experiment_id=dict(mandatory=True,),
        project_id=dict(mandatory=True,),
        pwd=dict(),
        reconstruction_id=dict(xor=["assessor_id"],),
        server=dict(mandatory=True, requires=["user", "pwd"], xor=["config"],),
        share=dict(usedefault=True,),
        subject_id=dict(mandatory=True,),
        user=dict(),
    )
    inputs = XNATSink.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import VolSymm


def test_VolSymm_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        config_file=dict(argstr="-config_file %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        fit_linear=dict(argstr="-linear",),
        fit_nonlinear=dict(argstr="-nonlinear",),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-3,),
        input_grid_files=dict(),
        nofit=dict(argstr="-nofit",),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_file"],
            name_template="%s_vol_symm.mnc",
            position=-1,
        ),
        trans_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            keep_extension=False,
            name_source=["input_file"],
            name_template="%s_vol_symm.xfm",
            position=-2,
        ),
        verbose=dict(argstr="-verbose",),
        x=dict(argstr="-x",),
        y=dict(argstr="-y",),
        z=dict(argstr="-z",),
    )
    inputs = VolSymm.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_VolSymm_outputs():
    output_map = dict(
        output_file=dict(extensions=None,),
        output_grid=dict(extensions=None,),
        trans_file=dict(extensions=None,),
    )
    outputs = VolSymm.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import fcsv_to_hdf5


def test_fcsv_to_hdf5_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        landmarkGlobPattern=dict(argstr="--landmarkGlobPattern %s",),
        landmarkTypesList=dict(argstr="--landmarkTypesList %s", extensions=None,),
        landmarksInformationFile=dict(
            argstr="--landmarksInformationFile %s", hash_files=False,
        ),
        modelFile=dict(argstr="--modelFile %s", hash_files=False,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        versionID=dict(argstr="--versionID %s",),
    )
    inputs = fcsv_to_hdf5.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_fcsv_to_hdf5_outputs():
    output_map = dict(
        landmarksInformationFile=dict(extensions=None,),
        modelFile=dict(extensions=None,),
    )
    outputs = fcsv_to_hdf5.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import SurfaceSnapshots


def test_SurfaceSnapshots_inputs():
    input_map = dict(
        annot_file=dict(argstr="-annotation %s", extensions=None, xor=["annot_name"],),
        annot_name=dict(argstr="-annotation %s", xor=["annot_file"],),
        args=dict(argstr="%s",),
        colortable=dict(argstr="-colortable %s", extensions=None,),
        demean_overlay=dict(argstr="-zm",),
        environ=dict(nohash=True, usedefault=True,),
        hemi=dict(argstr="%s", mandatory=True, position=2,),
        identity_reg=dict(
            argstr="-overlay-reg-identity",
            xor=["overlay_reg", "identity_reg", "mni152_reg"],
        ),
        invert_overlay=dict(argstr="-invphaseflag 1",),
        label_file=dict(argstr="-label %s", extensions=None, xor=["label_name"],),
        label_name=dict(argstr="-label %s", xor=["label_file"],),
        label_outline=dict(argstr="-label-outline",),
        label_under=dict(argstr="-labels-under",),
        mni152_reg=dict(
            argstr="-mni152reg", xor=["overlay_reg", "identity_reg", "mni152_reg"],
        ),
        orig_suffix=dict(argstr="-orig %s",),
        overlay=dict(
            argstr="-overlay %s", extensions=None, requires=["overlay_range"],
        ),
        overlay_range=dict(argstr="%s",),
        overlay_range_offset=dict(argstr="-foffset %.3f",),
        overlay_reg=dict(
            argstr="-overlay-reg %s",
            extensions=None,
            xor=["overlay_reg", "identity_reg", "mni152_reg"],
        ),
        patch_file=dict(argstr="-patch %s", extensions=None,),
        reverse_overlay=dict(argstr="-revphaseflag 1",),
        screenshot_stem=dict(),
        show_color_scale=dict(argstr="-colscalebarflag 1",),
        show_color_text=dict(argstr="-colscaletext 1",),
        show_curv=dict(argstr="-curv", xor=["show_gray_curv"],),
        show_gray_curv=dict(argstr="-gray", xor=["show_curv"],),
        six_images=dict(),
        sphere_suffix=dict(argstr="-sphere %s",),
        stem_template_args=dict(requires=["screenshot_stem"],),
        subject_id=dict(argstr="%s", mandatory=True, position=1,),
        subjects_dir=dict(),
        surface=dict(argstr="%s", mandatory=True, position=3,),
        tcl_script=dict(argstr="%s", extensions=None, genfile=True,),
        truncate_overlay=dict(argstr="-truncphaseflag 1",),
    )
    inputs = SurfaceSnapshots.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SurfaceSnapshots_outputs():
    output_map = dict(snapshots=dict(),)
    outputs = SurfaceSnapshots.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import JointHistogram


def test_JointHistogram_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputMaskVolumeInXAxis=dict(
            argstr="--inputMaskVolumeInXAxis %s", extensions=None,
        ),
        inputMaskVolumeInYAxis=dict(
            argstr="--inputMaskVolumeInYAxis %s", extensions=None,
        ),
        inputVolumeInXAxis=dict(argstr="--inputVolumeInXAxis %s", extensions=None,),
        inputVolumeInYAxis=dict(argstr="--inputVolumeInYAxis %s", extensions=None,),
        outputJointHistogramImage=dict(argstr="--outputJointHistogramImage %s",),
        verbose=dict(argstr="--verbose ",),
    )
    inputs = JointHistogram.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_JointHistogram_outputs():
    output_map = dict()
    outputs = JointHistogram.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Cluster


def test_Cluster_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        connectivity=dict(argstr="--connectivity=%d",),
        cope_file=dict(argstr="--cope=%s", extensions=None,),
        dlh=dict(argstr="--dlh=%.10f",),
        environ=dict(nohash=True, usedefault=True,),
        find_min=dict(argstr="--min", usedefault=True,),
        fractional=dict(argstr="--fractional", usedefault=True,),
        in_file=dict(argstr="--in=%s", extensions=None, mandatory=True,),
        minclustersize=dict(argstr="--minclustersize", usedefault=True,),
        no_table=dict(argstr="--no_table", usedefault=True,),
        num_maxima=dict(argstr="--num=%d",),
        out_index_file=dict(argstr="--oindex=%s", hash_files=False,),
        out_localmax_txt_file=dict(argstr="--olmax=%s", hash_files=False,),
        out_localmax_vol_file=dict(argstr="--olmaxim=%s", hash_files=False,),
        out_max_file=dict(argstr="--omax=%s", hash_files=False,),
        out_mean_file=dict(argstr="--omean=%s", hash_files=False,),
        out_pval_file=dict(argstr="--opvals=%s", hash_files=False,),
        out_size_file=dict(argstr="--osize=%s", hash_files=False,),
        out_threshold_file=dict(argstr="--othresh=%s", hash_files=False,),
        output_type=dict(),
        peak_distance=dict(argstr="--peakdist=%.10f",),
        pthreshold=dict(argstr="--pthresh=%.10f", requires=["dlh", "volume"],),
        std_space_file=dict(argstr="--stdvol=%s", extensions=None,),
        threshold=dict(argstr="--thresh=%.10f", mandatory=True,),
        use_mm=dict(argstr="--mm", usedefault=True,),
        volume=dict(argstr="--volume=%d",),
        warpfield_file=dict(argstr="--warpvol=%s", extensions=None,),
        xfm_file=dict(argstr="--xfm=%s", extensions=None,),
    )
    inputs = Cluster.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Cluster_outputs():
    output_map = dict(
        index_file=dict(extensions=None,),
        localmax_txt_file=dict(extensions=None,),
        localmax_vol_file=dict(extensions=None,),
        max_file=dict(extensions=None,),
        mean_file=dict(extensions=None,),
        pval_file=dict(extensions=None,),
        size_file=dict(extensions=None,),
        threshold_file=dict(extensions=None,),
    )
    outputs = Cluster.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import ACPCTransform


def test_ACPCTransform_inputs():
    input_map = dict(
        acpc=dict(argstr="--acpc %s...",),
        args=dict(argstr="%s",),
        debugSwitch=dict(argstr="--debugSwitch ",),
        environ=dict(nohash=True, usedefault=True,),
        midline=dict(argstr="--midline %s...",),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
    )
    inputs = ACPCTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ACPCTransform_outputs():
    output_map = dict(outputTransform=dict(extensions=None,),)
    outputs = ACPCTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import VolumeMask


def test_VolumeMask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        aseg=dict(extensions=None, xor=["in_aseg"],),
        copy_inputs=dict(),
        environ=dict(nohash=True, usedefault=True,),
        in_aseg=dict(argstr="--aseg_name %s", extensions=None, xor=["aseg"],),
        left_ribbonlabel=dict(argstr="--label_left_ribbon %d", mandatory=True,),
        left_whitelabel=dict(argstr="--label_left_white %d", mandatory=True,),
        lh_pial=dict(extensions=None, mandatory=True,),
        lh_white=dict(extensions=None, mandatory=True,),
        rh_pial=dict(extensions=None, mandatory=True,),
        rh_white=dict(extensions=None, mandatory=True,),
        right_ribbonlabel=dict(argstr="--label_right_ribbon %d", mandatory=True,),
        right_whitelabel=dict(argstr="--label_right_white %d", mandatory=True,),
        save_ribbon=dict(argstr="--save_ribbon",),
        subject_id=dict(argstr="%s", mandatory=True, position=-1, usedefault=True,),
        subjects_dir=dict(),
    )
    inputs = VolumeMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_VolumeMask_outputs():
    output_map = dict(
        lh_ribbon=dict(extensions=None,),
        out_ribbon=dict(extensions=None,),
        rh_ribbon=dict(extensions=None,),
    )
    outputs = VolumeMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import LocalBistat


def test_LocalBistat_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask", xor=["weight_file"],),
        environ=dict(nohash=True, usedefault=True,),
        in_file1=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        in_file2=dict(argstr="%s", extensions=None, mandatory=True, position=-1,),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        neighborhood=dict(argstr="-nbhd '%s(%s)'", mandatory=True,),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            keep_extension=True,
            name_source="in_file1",
            name_template="%s_bistat",
            position=0,
        ),
        outputtype=dict(),
        stat=dict(argstr="-stat %s...", mandatory=True,),
        weight_file=dict(argstr="-weight %s", extensions=None, xor=["automask"],),
    )
    inputs = LocalBistat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_LocalBistat_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = LocalBistat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractResampleDWIInPlace


def test_gtractResampleDWIInPlace_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debugLevel=dict(argstr="--debugLevel %d",),
        environ=dict(nohash=True, usedefault=True,),
        imageOutputSize=dict(argstr="--imageOutputSize %s", sep=",",),
        inputTransform=dict(argstr="--inputTransform %s", extensions=None,),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputResampledB0=dict(argstr="--outputResampledB0 %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        referenceVolume=dict(argstr="--referenceVolume %s", extensions=None,),
        warpDWITransform=dict(argstr="--warpDWITransform %s", extensions=None,),
    )
    inputs = gtractResampleDWIInPlace.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractResampleDWIInPlace_outputs():
    output_map = dict(
        outputResampledB0=dict(extensions=None,), outputVolume=dict(extensions=None,),
    )
    outputs = gtractResampleDWIInPlace.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsresample import BRAINSResample


def test_BRAINSResample_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        defaultValue=dict(argstr="--defaultValue %f",),
        deformationVolume=dict(argstr="--deformationVolume %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        gridSpacing=dict(argstr="--gridSpacing %s", sep=",",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        interpolationMode=dict(argstr="--interpolationMode %s",),
        inverseTransform=dict(argstr="--inverseTransform ",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        pixelType=dict(argstr="--pixelType %s",),
        referenceVolume=dict(argstr="--referenceVolume %s", extensions=None,),
        warpTransform=dict(argstr="--warpTransform %s", extensions=None,),
    )
    inputs = BRAINSResample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSResample_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = BRAINSResample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brains import BRAINSSnapShotWriter


def test_BRAINSSnapShotWriter_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputBinaryVolumes=dict(argstr="--inputBinaryVolumes %s...",),
        inputPlaneDirection=dict(argstr="--inputPlaneDirection %s", sep=",",),
        inputSliceToExtractInIndex=dict(
            argstr="--inputSliceToExtractInIndex %s", sep=",",
        ),
        inputSliceToExtractInPercent=dict(
            argstr="--inputSliceToExtractInPercent %s", sep=",",
        ),
        inputSliceToExtractInPhysicalPoint=dict(
            argstr="--inputSliceToExtractInPhysicalPoint %s", sep=",",
        ),
        inputVolumes=dict(argstr="--inputVolumes %s...",),
        outputFilename=dict(argstr="--outputFilename %s", hash_files=False,),
    )
    inputs = BRAINSSnapShotWriter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSSnapShotWriter_outputs():
    output_map = dict(outputFilename=dict(extensions=None,),)
    outputs = BRAINSSnapShotWriter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Calc


def test_Calc_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        check_dimensions=dict(
            argstr="-check_dimensions", xor=("check_dimensions", "no_check_dimensions"),
        ),
        clobber=dict(argstr="-clobber", usedefault=True,),
        copy_header=dict(argstr="-copy_header", xor=("copy_header", "no_copy_header"),),
        debug=dict(argstr="-debug",),
        environ=dict(nohash=True, usedefault=True,),
        eval_width=dict(argstr="-eval_width %s",),
        expfile=dict(
            argstr="-expfile %s",
            extensions=None,
            mandatory=True,
            xor=("expression", "expfile"),
        ),
        expression=dict(
            argstr="-expression '%s'", mandatory=True, xor=("expression", "expfile"),
        ),
        filelist=dict(
            argstr="-filelist %s",
            extensions=None,
            mandatory=True,
            xor=("input_files", "filelist"),
        ),
        format_byte=dict(
            argstr="-byte",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_double=dict(
            argstr="-double",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_filetype=dict(
            argstr="-filetype",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_float=dict(
            argstr="-float",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_int=dict(
            argstr="-int",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_long=dict(
            argstr="-long",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_short=dict(
            argstr="-short",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_signed=dict(
            argstr="-signed",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        format_unsigned=dict(
            argstr="-unsigned",
            xor=(
                "format_filetype",
                "format_byte",
                "format_short",
                "format_int",
                "format_long",
                "format_float",
                "format_double",
                "format_signed",
                "format_unsigned",
            ),
        ),
        ignore_nan=dict(argstr="-ignore_nan",),
        input_files=dict(argstr="%s", mandatory=True, position=-2, sep=" ",),
        max_buffer_size_in_kb=dict(argstr="-max_buffer_size_in_kb %d",),
        no_check_dimensions=dict(
            argstr="-nocheck_dimensions",
            xor=("check_dimensions", "no_check_dimensions"),
        ),
        no_copy_header=dict(
            argstr="-nocopy_header", xor=("copy_header", "no_copy_header"),
        ),
        outfiles=dict(),
        output_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            hash_files=False,
            name_source=["input_files"],
            name_template="%s_calc.mnc",
            position=-1,
        ),
        output_illegal=dict(
            argstr="-illegal_value",
            xor=("output_nan", "output_zero", "output_illegal_value"),
        ),
        output_nan=dict(
            argstr="-nan", xor=("output_nan", "output_zero", "output_illegal_value"),
        ),
        output_zero=dict(
            argstr="-zero", xor=("output_nan", "output_zero", "output_illegal_value"),
        ),
        propagate_nan=dict(argstr="-propagate_nan",),
        quiet=dict(argstr="-quiet", xor=("verbose", "quiet"),),
        two=dict(argstr="-2",),
        verbose=dict(argstr="-verbose", xor=("verbose", "quiet"),),
        voxel_range=dict(argstr="-range %d %d",),
    )
    inputs = Calc.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Calc_outputs():
    output_map = dict(output_file=dict(extensions=None,),)
    outputs = Calc.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..longitudinal import RobustTemplate


def test_RobustTemplate_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        auto_detect_sensitivity=dict(
            argstr="--satit", mandatory=True, xor=["outlier_sensitivity"],
        ),
        average_metric=dict(argstr="--average %d",),
        environ=dict(nohash=True, usedefault=True,),
        fixed_timepoint=dict(argstr="--fixtp",),
        in_files=dict(argstr="--mov %s", mandatory=True,),
        in_intensity_scales=dict(argstr="--iscalein %s",),
        initial_timepoint=dict(argstr="--inittp %d",),
        initial_transforms=dict(argstr="--ixforms %s",),
        intensity_scaling=dict(argstr="--iscale",),
        no_iteration=dict(argstr="--noit",),
        num_threads=dict(),
        out_file=dict(
            argstr="--template %s", extensions=None, mandatory=True, usedefault=True,
        ),
        outlier_sensitivity=dict(
            argstr="--sat %.4f", mandatory=True, xor=["auto_detect_sensitivity"],
        ),
        scaled_intensity_outputs=dict(argstr="--iscaleout %s",),
        subjects_dir=dict(),
        subsample_threshold=dict(argstr="--subsample %d",),
        transform_outputs=dict(argstr="--lta %s",),
    )
    inputs = RobustTemplate.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RobustTemplate_outputs():
    output_map = dict(
        out_file=dict(extensions=None,),
        scaled_intensity_outputs=dict(),
        transform_outputs=dict(),
    )
    outputs = RobustTemplate.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import OneDToolPy


def test_OneDToolPy_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        censor_motion=dict(argstr="-censor_motion %f %s",),
        censor_prev_TR=dict(argstr="-censor_prev_TR",),
        demean=dict(argstr="-demean",),
        derivative=dict(argstr="-derivative",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-infile %s", extensions=None, mandatory=True,),
        out_file=dict(
            argstr="-write %s", extensions=None, xor=["show_cormat_warnings"],
        ),
        outputtype=dict(),
        py27_path=dict(usedefault=True,),
        set_nruns=dict(argstr="-set_nruns %d",),
        show_censor_count=dict(argstr="-show_censor_count",),
        show_cormat_warnings=dict(
            argstr="-show_cormat_warnings |& tee %s",
            extensions=None,
            position=-1,
            xor=["out_file"],
        ),
        show_indices_interest=dict(argstr="-show_indices_interest",),
        show_trs_run=dict(argstr="-show_trs_run %d",),
        show_trs_uncensored=dict(argstr="-show_trs_uncensored %s",),
    )
    inputs = OneDToolPy.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_OneDToolPy_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = OneDToolPy.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..asl import FitAsl


def test_FitAsl_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        cbf_file=dict(
            argstr="-cbf %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_cbf.nii.gz",
        ),
        dpld=dict(argstr="-dPLD %f",),
        dt_inv2=dict(argstr="-dTinv2 %f",),
        eff=dict(argstr="-eff %f",),
        environ=dict(nohash=True, usedefault=True,),
        error_file=dict(
            argstr="-error %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_error.nii.gz",
        ),
        gm_plasma=dict(argstr="-gmL %f",),
        gm_t1=dict(argstr="-gmT1 %f",),
        gm_ttt=dict(argstr="-gmTTT %f",),
        ir_output=dict(argstr="-IRoutput %s", extensions=None,),
        ir_volume=dict(argstr="-IRvolume %s", extensions=None,),
        ldd=dict(argstr="-LDD %f",),
        m0map=dict(argstr="-m0map %s", extensions=None,),
        m0mape=dict(argstr="-m0mape %s", extensions=None,),
        mask=dict(argstr="-mask %s", extensions=None, position=2,),
        mul=dict(argstr="-mul %f",),
        mulgm=dict(argstr="-sig",),
        out=dict(argstr="-out %f",),
        pasl=dict(argstr="-pasl",),
        pcasl=dict(argstr="-pcasl",),
        plasma_coeff=dict(argstr="-L %f",),
        pld=dict(argstr="-PLD %f",),
        pv0=dict(argstr="-pv0 %d",),
        pv2=dict(argstr="-pv2 %d",),
        pv3=dict(argstr="-pv3 %d %d %d",),
        pv_threshold=dict(argstr="-pvthreshold",),
        seg=dict(argstr="-seg %s", extensions=None,),
        segstyle=dict(argstr="-segstyle",),
        sig=dict(argstr="-sig",),
        source_file=dict(
            argstr="-source %s", extensions=None, mandatory=True, position=1,
        ),
        syn_file=dict(
            argstr="-syn %s",
            extensions=None,
            name_source=["source_file"],
            name_template="%s_syn.nii.gz",
        ),
        t1_art_cmp=dict(argstr="-T1a %f",),
        t1map=dict(argstr="-t1map %s", extensions=None,),
        t_inv1=dict(argstr="-Tinv1 %f",),
        t_inv2=dict(argstr="-Tinv2 %f",),
        wm_plasma=dict(argstr="-wmL %f",),
        wm_t1=dict(argstr="-wmT1 %f",),
        wm_ttt=dict(argstr="-wmTTT %f",),
    )
    inputs = FitAsl.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FitAsl_outputs():
    output_map = dict(
        cbf_file=dict(extensions=None,),
        error_file=dict(extensions=None,),
        syn_file=dict(extensions=None,),
    )
    outputs = FitAsl.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Refit


def test_Refit_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        atrcopy=dict(argstr="-atrcopy %s %s",),
        atrfloat=dict(argstr="-atrfloat %s %s",),
        atrint=dict(argstr="-atrint %s %s",),
        atrstring=dict(argstr="-atrstring %s %s",),
        deoblique=dict(argstr="-deoblique",),
        duporigin_file=dict(argstr="-duporigin %s", extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="%s", copyfile=True, extensions=None, mandatory=True, position=-1,
        ),
        nosaveatr=dict(argstr="-nosaveatr",),
        saveatr=dict(argstr="-saveatr",),
        space=dict(argstr="-space %s",),
        xdel=dict(argstr="-xdel %f",),
        xorigin=dict(argstr="-xorigin %s",),
        xyzscale=dict(argstr="-xyzscale %f",),
        ydel=dict(argstr="-ydel %f",),
        yorigin=dict(argstr="-yorigin %s",),
        zdel=dict(argstr="-zdel %f",),
        zorigin=dict(argstr="-zorigin %s",),
    )
    inputs = Refit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Refit_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Refit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsfit import BRAINSFit


def test_BRAINSFit_inputs():
    input_map = dict(
        NEVER_USE_THIS_FLAG_IT_IS_OUTDATED_00=dict(
            argstr="--NEVER_USE_THIS_FLAG_IT_IS_OUTDATED_00 ",
        ),
        NEVER_USE_THIS_FLAG_IT_IS_OUTDATED_01=dict(
            argstr="--NEVER_USE_THIS_FLAG_IT_IS_OUTDATED_01 ",
        ),
        NEVER_USE_THIS_FLAG_IT_IS_OUTDATED_02=dict(
            argstr="--NEVER_USE_THIS_FLAG_IT_IS_OUTDATED_02 ",
        ),
        ROIAutoClosingSize=dict(argstr="--ROIAutoClosingSize %f",),
        ROIAutoDilateSize=dict(argstr="--ROIAutoDilateSize %f",),
        args=dict(argstr="%s",),
        backgroundFillValue=dict(argstr="--backgroundFillValue %f",),
        bsplineTransform=dict(argstr="--bsplineTransform %s", hash_files=False,),
        costFunctionConvergenceFactor=dict(
            argstr="--costFunctionConvergenceFactor %f",
        ),
        costMetric=dict(argstr="--costMetric %s",),
        debugLevel=dict(argstr="--debugLevel %d",),
        environ=dict(nohash=True, usedefault=True,),
        failureExitCode=dict(argstr="--failureExitCode %d",),
        fixedBinaryVolume=dict(argstr="--fixedBinaryVolume %s", extensions=None,),
        fixedVolume=dict(argstr="--fixedVolume %s", extensions=None,),
        fixedVolumeTimeIndex=dict(argstr="--fixedVolumeTimeIndex %d",),
        forceMINumberOfThreads=dict(argstr="--forceMINumberOfThreads %d",),
        gui=dict(argstr="--gui ",),
        histogramMatch=dict(argstr="--histogramMatch ",),
        initialTransform=dict(argstr="--initialTransform %s", extensions=None,),
        initializeTransformMode=dict(argstr="--initializeTransformMode %s",),
        interpolationMode=dict(argstr="--interpolationMode %s",),
        linearTransform=dict(argstr="--linearTransform %s", hash_files=False,),
        maskInferiorCutOffFromCenter=dict(argstr="--maskInferiorCutOffFromCenter %f",),
        maskProcessingMode=dict(argstr="--maskProcessingMode %s",),
        maxBSplineDisplacement=dict(argstr="--maxBSplineDisplacement %f",),
        maximumStepLength=dict(argstr="--maximumStepLength %f",),
        medianFilterSize=dict(argstr="--medianFilterSize %s", sep=",",),
        minimumStepLength=dict(argstr="--minimumStepLength %s", sep=",",),
        movingBinaryVolume=dict(argstr="--movingBinaryVolume %s", extensions=None,),
        movingVolume=dict(argstr="--movingVolume %s", extensions=None,),
        movingVolumeTimeIndex=dict(argstr="--movingVolumeTimeIndex %d",),
        numberOfHistogramBins=dict(argstr="--numberOfHistogramBins %d",),
        numberOfIterations=dict(argstr="--numberOfIterations %s", sep=",",),
        numberOfMatchPoints=dict(argstr="--numberOfMatchPoints %d",),
        numberOfSamples=dict(argstr="--numberOfSamples %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputFixedVolumeROI=dict(
            argstr="--outputFixedVolumeROI %s", hash_files=False,
        ),
        outputMovingVolumeROI=dict(
            argstr="--outputMovingVolumeROI %s", hash_files=False,
        ),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        outputVolumePixelType=dict(argstr="--outputVolumePixelType %s",),
        permitParameterVariation=dict(argstr="--permitParameterVariation %s", sep=",",),
        projectedGradientTolerance=dict(argstr="--projectedGradientTolerance %f",),
        promptUser=dict(argstr="--promptUser ",),
        relaxationFactor=dict(argstr="--relaxationFactor %f",),
        removeIntensityOutliers=dict(argstr="--removeIntensityOutliers %f",),
        reproportionScale=dict(argstr="--reproportionScale %f",),
        scaleOutputValues=dict(argstr="--scaleOutputValues ",),
        skewScale=dict(argstr="--skewScale %f",),
        splineGridSize=dict(argstr="--splineGridSize %s", sep=",",),
        strippedOutputTransform=dict(
            argstr="--strippedOutputTransform %s", hash_files=False,
        ),
        transformType=dict(argstr="--transformType %s", sep=",",),
        translationScale=dict(argstr="--translationScale %f",),
        useAffine=dict(argstr="--useAffine ",),
        useBSpline=dict(argstr="--useBSpline ",),
        useCachingOfBSplineWeightsMode=dict(
            argstr="--useCachingOfBSplineWeightsMode %s",
        ),
        useExplicitPDFDerivativesMode=dict(
            argstr="--useExplicitPDFDerivativesMode %s",
        ),
        useRigid=dict(argstr="--useRigid ",),
        useScaleSkewVersor3D=dict(argstr="--useScaleSkewVersor3D ",),
        useScaleVersor3D=dict(argstr="--useScaleVersor3D ",),
        writeOutputTransformInFloat=dict(argstr="--writeOutputTransformInFloat ",),
        writeTransformOnFailure=dict(argstr="--writeTransformOnFailure ",),
    )
    inputs = BRAINSFit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSFit_outputs():
    output_map = dict(
        bsplineTransform=dict(extensions=None,),
        linearTransform=dict(extensions=None,),
        outputFixedVolumeROI=dict(extensions=None,),
        outputMovingVolumeROI=dict(extensions=None,),
        outputTransform=dict(extensions=None,),
        outputVolume=dict(extensions=None,),
        strippedOutputTransform=dict(extensions=None,),
    )
    outputs = BRAINSFit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utilities import GenerateEdgeMapImage


def test_GenerateEdgeMapImage_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputMRVolumes=dict(argstr="--inputMRVolumes %s...",),
        inputMask=dict(argstr="--inputMask %s", extensions=None,),
        lowerPercentileMatching=dict(argstr="--lowerPercentileMatching %f",),
        maximumOutputRange=dict(argstr="--maximumOutputRange %d",),
        minimumOutputRange=dict(argstr="--minimumOutputRange %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputEdgeMap=dict(argstr="--outputEdgeMap %s", hash_files=False,),
        outputMaximumGradientImage=dict(
            argstr="--outputMaximumGradientImage %s", hash_files=False,
        ),
        upperPercentileMatching=dict(argstr="--upperPercentileMatching %f",),
    )
    inputs = GenerateEdgeMapImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GenerateEdgeMapImage_outputs():
    output_map = dict(
        outputEdgeMap=dict(extensions=None,),
        outputMaximumGradientImage=dict(extensions=None,),
    )
    outputs = GenerateEdgeMapImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..c3 import C3d


def test_C3d_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", mandatory=True, position=1,),
        interp=dict(argstr="-interpolation %s",),
        is_4d=dict(usedefault=True,),
        multicomp_split=dict(argstr="-mcr", position=0, usedefault=True,),
        out_file=dict(argstr="-o %s", extensions=None, position=-1, xor=["out_files"],),
        out_files=dict(argstr="-oo %s", position=-1, xor=["out_file"],),
        pix_type=dict(argstr="-type %s",),
        resample=dict(argstr="-resample %s",),
        scale=dict(argstr="-scale %s",),
        shift=dict(argstr="-shift %s",),
        smooth=dict(argstr="-smooth %s",),
    )
    inputs = C3d.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_C3d_outputs():
    output_map = dict(out_files=dict(),)
    outputs = C3d.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..minc import Blur


def test_Blur_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        clobber=dict(argstr="-clobber", usedefault=True,),
        dimensions=dict(argstr="-dimensions %s",),
        environ=dict(nohash=True, usedefault=True,),
        fwhm=dict(
            argstr="-fwhm %s", mandatory=True, xor=("fwhm", "fwhm3d", "standard_dev"),
        ),
        fwhm3d=dict(
            argstr="-3dfwhm %s %s %s",
            mandatory=True,
            xor=("fwhm", "fwhm3d", "standard_dev"),
        ),
        gaussian=dict(argstr="-gaussian", xor=("gaussian", "rect"),),
        gradient=dict(argstr="-gradient",),
        input_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        no_apodize=dict(argstr="-no_apodize",),
        output_file_base=dict(argstr="%s", extensions=None, position=-1,),
        partial=dict(argstr="-partial",),
        rect=dict(argstr="-rect", xor=("gaussian", "rect"),),
        standard_dev=dict(
            argstr="-standarddev %s",
            mandatory=True,
            xor=("fwhm", "fwhm3d", "standard_dev"),
        ),
    )
    inputs = Blur.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Blur_outputs():
    output_map = dict(
        gradient_dxyz=dict(extensions=None,),
        output_file=dict(extensions=None,),
        partial_dx=dict(extensions=None,),
        partial_dxyz=dict(extensions=None,),
        partial_dy=dict(extensions=None,),
        partial_dz=dict(extensions=None,),
    )
    outputs = Blur.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..io import XNATSource


def test_XNATSource_inputs():
    input_map = dict(
        cache_dir=dict(),
        config=dict(extensions=None, mandatory=True, xor=["server"],),
        pwd=dict(),
        query_template=dict(mandatory=True,),
        query_template_args=dict(usedefault=True,),
        server=dict(mandatory=True, requires=["user", "pwd"], xor=["config"],),
        user=dict(),
    )
    inputs = XNATSource.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_XNATSource_outputs():
    output_map = dict()
    outputs = XNATSource.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..diffusion import DWIConvert


def test_DWIConvert_inputs():
    input_map = dict(
        allowLossyConversion=dict(argstr="--allowLossyConversion ",),
        args=dict(argstr="%s",),
        conversionMode=dict(argstr="--conversionMode %s",),
        environ=dict(nohash=True, usedefault=True,),
        fMRI=dict(argstr="--fMRI ",),
        fslNIFTIFile=dict(argstr="--fslNIFTIFile %s", extensions=None,),
        gradientVectorFile=dict(argstr="--gradientVectorFile %s", hash_files=False,),
        inputBValues=dict(argstr="--inputBValues %s", extensions=None,),
        inputBVectors=dict(argstr="--inputBVectors %s", extensions=None,),
        inputDicomDirectory=dict(argstr="--inputDicomDirectory %s",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        outputBValues=dict(argstr="--outputBValues %s", hash_files=False,),
        outputBVectors=dict(argstr="--outputBVectors %s", hash_files=False,),
        outputDirectory=dict(argstr="--outputDirectory %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        smallGradientThreshold=dict(argstr="--smallGradientThreshold %f",),
        transposeInputBVectors=dict(argstr="--transposeInputBVectors ",),
        useBMatrixGradientDirections=dict(argstr="--useBMatrixGradientDirections ",),
        useIdentityMeaseurementFrame=dict(argstr="--useIdentityMeaseurementFrame ",),
        writeProtocolGradientsFile=dict(argstr="--writeProtocolGradientsFile ",),
    )
    inputs = DWIConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DWIConvert_outputs():
    output_map = dict(
        gradientVectorFile=dict(extensions=None,),
        outputBValues=dict(extensions=None,),
        outputBVectors=dict(extensions=None,),
        outputDirectory=dict(),
        outputVolume=dict(extensions=None,),
    )
    outputs = DWIConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..n4itkbiasfieldcorrection import N4ITKBiasFieldCorrection


def test_N4ITKBiasFieldCorrection_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        bsplineorder=dict(argstr="--bsplineorder %d",),
        convergencethreshold=dict(argstr="--convergencethreshold %f",),
        environ=dict(nohash=True, usedefault=True,),
        histogramsharpening=dict(argstr="--histogramsharpening %s", sep=",",),
        inputimage=dict(argstr="--inputimage %s", extensions=None,),
        iterations=dict(argstr="--iterations %s", sep=",",),
        maskimage=dict(argstr="--maskimage %s", extensions=None,),
        meshresolution=dict(argstr="--meshresolution %s", sep=",",),
        outputbiasfield=dict(argstr="--outputbiasfield %s", hash_files=False,),
        outputimage=dict(argstr="--outputimage %s", hash_files=False,),
        shrinkfactor=dict(argstr="--shrinkfactor %d",),
        splinedistance=dict(argstr="--splinedistance %f",),
        weightimage=dict(argstr="--weightimage %s", extensions=None,),
    )
    inputs = N4ITKBiasFieldCorrection.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_N4ITKBiasFieldCorrection_outputs():
    output_map = dict(
        outputbiasfield=dict(extensions=None,), outputimage=dict(extensions=None,),
    )
    outputs = N4ITKBiasFieldCorrection.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import FNIRT


def test_FNIRT_inputs():
    input_map = dict(
        affine_file=dict(argstr="--aff=%s", extensions=None,),
        apply_inmask=dict(argstr="--applyinmask=%s", sep=",", xor=["skip_inmask"],),
        apply_intensity_mapping=dict(
            argstr="--estint=%s", sep=",", xor=["skip_intensity_mapping"],
        ),
        apply_refmask=dict(argstr="--applyrefmask=%s", sep=",", xor=["skip_refmask"],),
        args=dict(argstr="%s",),
        bias_regularization_lambda=dict(argstr="--biaslambda=%f",),
        biasfield_resolution=dict(argstr="--biasres=%d,%d,%d",),
        config_file=dict(argstr="--config=%s",),
        derive_from_ref=dict(argstr="--refderiv",),
        environ=dict(nohash=True, usedefault=True,),
        field_file=dict(argstr="--fout=%s", hash_files=False,),
        fieldcoeff_file=dict(argstr="--cout=%s",),
        hessian_precision=dict(argstr="--numprec=%s",),
        in_file=dict(argstr="--in=%s", extensions=None, mandatory=True,),
        in_fwhm=dict(argstr="--infwhm=%s", sep=",",),
        in_intensitymap_file=dict(argstr="--intin=%s", copyfile=False,),
        inmask_file=dict(argstr="--inmask=%s", extensions=None,),
        inmask_val=dict(argstr="--impinval=%f",),
        intensity_mapping_model=dict(argstr="--intmod=%s",),
        intensity_mapping_order=dict(argstr="--intorder=%d",),
        inwarp_file=dict(argstr="--inwarp=%s", extensions=None,),
        jacobian_file=dict(argstr="--jout=%s", hash_files=False,),
        jacobian_range=dict(argstr="--jacrange=%f,%f",),
        log_file=dict(
            argstr="--logout=%s", extensions=None, genfile=True, hash_files=False,
        ),
        max_nonlin_iter=dict(argstr="--miter=%s", sep=",",),
        modulatedref_file=dict(argstr="--refout=%s", hash_files=False,),
        out_intensitymap_file=dict(argstr="--intout=%s", hash_files=False,),
        output_type=dict(),
        ref_file=dict(argstr="--ref=%s", extensions=None, mandatory=True,),
        ref_fwhm=dict(argstr="--reffwhm=%s", sep=",",),
        refmask_file=dict(argstr="--refmask=%s", extensions=None,),
        refmask_val=dict(argstr="--imprefval=%f",),
        regularization_lambda=dict(argstr="--lambda=%s", sep=",",),
        regularization_model=dict(argstr="--regmod=%s",),
        skip_implicit_in_masking=dict(argstr="--impinm=0",),
        skip_implicit_ref_masking=dict(argstr="--imprefm=0",),
        skip_inmask=dict(argstr="--applyinmask=0", xor=["apply_inmask"],),
        skip_intensity_mapping=dict(
            argstr="--estint=0", xor=["apply_intensity_mapping"],
        ),
        skip_lambda_ssq=dict(argstr="--ssqlambda=0",),
        skip_refmask=dict(argstr="--applyrefmask=0", xor=["apply_refmask"],),
        spline_order=dict(argstr="--splineorder=%d",),
        subsampling_scheme=dict(argstr="--subsamp=%s", sep=",",),
        warp_resolution=dict(argstr="--warpres=%d,%d,%d",),
        warped_file=dict(
            argstr="--iout=%s", extensions=None, genfile=True, hash_files=False,
        ),
    )
    inputs = FNIRT.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FNIRT_outputs():
    output_map = dict(
        field_file=dict(extensions=None,),
        fieldcoeff_file=dict(extensions=None,),
        jacobian_file=dict(extensions=None,),
        log_file=dict(extensions=None,),
        modulatedref_file=dict(extensions=None,),
        out_intensitymap_file=dict(),
        warped_file=dict(extensions=None,),
    )
    outputs = FNIRT.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
